@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __MTX_COMMON_BYTE_BUFFER_H
-#define __MTX_COMMON_BYTE_BUFFER_H
+#ifndef MTX_COMMON_BYTE_BUFFER_H
+#define MTX_COMMON_BYTE_BUFFER_H
 
 #include "common/common_pch.h"
 
@@ -108,4 +108,4 @@ private:
 
 typedef std::shared_ptr<byte_buffer_c> byte_buffer_cptr;
 
-#endif // __MTX_COMMON_BYTE_BUFFER_H
+#endif // MTX_COMMON_BYTE_BUFFER_H
