@@ -215,17 +215,17 @@ parse_simple_chapters(mm_text_io_c *in,
         if (!edition)
           edition = &GetChild<KaxEditionEntry>(*chaps);
 
-        atom                                                 = &GetFirstOrNextChild<KaxChapterAtom>(*edition, atom);
-        GetChildAs<KaxChapterUID, EbmlUInteger>(*atom)       = create_unique_number(UNIQUE_CHAPTER_IDS);
-        GetChildAs<KaxChapterTimeStart, EbmlUInteger>(*atom) = (start - offset) * 1000000;
+        atom = &GetFirstOrNextChild<KaxChapterAtom>(*edition, atom);
+        GetChild<KaxChapterUID>(*atom).SetValue(create_unique_number(UNIQUE_CHAPTER_IDS));
+        GetChild<KaxChapterTimeStart>(*atom).SetValue((start - offset) * 1000000);
 
-        KaxChapterDisplay *display = &GetChild<KaxChapterDisplay>(*atom);
+        auto &display = GetChild<KaxChapterDisplay>(*atom);
 
-        GetChildAs<KaxChapterString,   EbmlUnicodeString>(*display) = cstrutf8_to_UTFstring(do_convert ? cc_utf8->utf8(name) : name);
-        GetChildAs<KaxChapterLanguage, EbmlString>(*display)        = use_language;
+        GetChild<KaxChapterString>(display).SetValue(cstrutf8_to_UTFstring(do_convert ? cc_utf8->utf8(name) : name));
+        GetChild<KaxChapterLanguage>(display).SetValue(use_language);
 
         if (!g_default_chapter_country.empty())
-          GetChildAs<KaxChapterCountry, EbmlString>(*display)       = g_default_chapter_country;
+          GetChild<KaxChapterCountry>(display).SetValue(g_default_chapter_country);
 
         ++num;
       }
@@ -344,6 +344,8 @@ parse_chapters(mm_text_io_c *in,
                KaxTags **tags) {
   assert(in);
 
+  std::string error;
+
   try {
     if (probe_simple_chapters(in)) {
       if (is_simple_format)
@@ -363,11 +365,21 @@ parse_chapters(mm_text_io_c *in,
       return select_chapters_in_timeframe(chapters.get(), min_tc, max_tc, offset) ? chapters : kax_chapters_cptr{};
     }
 
-    throw mtx::chapter_parser_x(boost::format(Y("Unknown chapter file format in '%1%'. It does not contain a supported chapter format.\n")) % in->get_file_name());
+    error = (boost::format(Y("Unknown chapter file format in '%1%'. It does not contain a supported chapter format.\n")) % in->get_file_name()).str();
   } catch (mtx::chapter_parser_x &e) {
+    error = e.error();
+  } catch (mtx::mm_io::exception &ex) {
+    error = (boost::format(Y("The XML chapter file '%1%' could not be read.\n")) % in->get_file_name()).str();
+  } catch (mtx::xml::xml_parser_x &ex) {
+    error = (boost::format(Y("The XML chapter file '%1%' contains an error at position %3%: %2%\n")) % in->get_file_name() % ex.result().description() % ex.result().offset).str();
+  } catch (mtx::xml::exception &ex) {
+    error = (boost::format(Y("The XML chapter file '%1%' contains an error: %2%\n")) % in->get_file_name() % ex.what()).str();
+  }
+
+  if (!error.empty()) {
     if (exception_on_error)
-      throw;
-    mxerror(e.error());
+      throw mtx::chapter_parser_x(error);
+    mxerror(error);
   }
 
   return kax_chapters_cptr{};
@@ -389,7 +401,7 @@ get_chapter_start(KaxChapterAtom &atom,
                   int64_t value_if_not_found) {
   KaxChapterTimeStart *start = FindChild<KaxChapterTimeStart>(&atom);
 
-  return !start ? value_if_not_found : int64_t(uint64(*start));
+  return !start ? value_if_not_found : static_cast<int64_t>(start->GetValue());
 }
 
 /** \brief Get the end timecode for a chapter atom.
@@ -408,7 +420,7 @@ get_chapter_end(KaxChapterAtom &atom,
                 int64_t value_if_not_found) {
   KaxChapterTimeEnd *end = FindChild<KaxChapterTimeEnd>(&atom);
 
-  return !end ? value_if_not_found : int64_t(uint64(*end));
+  return !end ? value_if_not_found : static_cast<int64_t>(end->GetValue());
 }
 
 /** \brief Get the name for a chapter atom.
@@ -446,7 +458,7 @@ int64_t
 get_chapter_uid(KaxChapterAtom &atom) {
   KaxChapterUID *uid = FindChild<KaxChapterUID>(&atom);
 
-  return !uid ? -1 : int64_t(uint64(*uid));
+  return !uid ? -1 : static_cast<int64_t>(uid->GetValue());
 }
 
 /** \brief Add missing mandatory elements
@@ -473,7 +485,7 @@ fix_mandatory_chapter_elements(EbmlElement *e) {
     GetChild<KaxEditionFlagHidden>(ee);
 
     if (!FindChild<KaxEditionUID>(&ee))
-      GetChildAs<KaxEditionUID, EbmlUInteger>(ee) = create_unique_number(UNIQUE_EDITION_IDS);
+      GetChild<KaxEditionUID>(ee).SetValue(create_unique_number(UNIQUE_EDITION_IDS));
 
   } else if (dynamic_cast<KaxChapterAtom *>(e)) {
     KaxChapterAtom &a = *static_cast<KaxChapterAtom *>(e);
@@ -482,25 +494,25 @@ fix_mandatory_chapter_elements(EbmlElement *e) {
     GetChild<KaxChapterFlagEnabled>(a);
 
     if (!FindChild<KaxChapterUID>(&a))
-      GetChildAs<KaxChapterUID, EbmlUInteger>(a) = create_unique_number(UNIQUE_CHAPTER_IDS);
+      GetChild<KaxChapterUID>(a).SetValue(create_unique_number(UNIQUE_CHAPTER_IDS));
 
     if (!FindChild<KaxChapterTimeStart>(&a))
-      GetChildAs<KaxChapterTimeStart, EbmlUInteger>(a) = 0;
+      GetChild<KaxChapterTimeStart>(a).SetValue(0);
 
   } else if (dynamic_cast<KaxChapterTrack *>(e)) {
     KaxChapterTrack &t = *static_cast<KaxChapterTrack *>(e);
 
     if (!FindChild<KaxChapterTrackNumber>(&t))
-      GetChildAs<KaxChapterTrackNumber, EbmlUInteger>(t) = 0;
+      GetChild<KaxChapterTrackNumber>(t).SetValue(0);
 
   } else if (dynamic_cast<KaxChapterDisplay *>(e)) {
     KaxChapterDisplay &d = *static_cast<KaxChapterDisplay *>(e);
 
     if (!FindChild<KaxChapterString>(&d))
-      GetChildAs<KaxChapterString, EbmlUnicodeString>(d) = L"";
+      GetChild<KaxChapterString>(d).SetValue(L"");
 
     if (!FindChild<KaxChapterLanguage>(&d))
-      GetChildAs<KaxChapterLanguage, EbmlString>(d) = "eng";
+      GetChild<KaxChapterLanguage>(d).SetValue("eng");
 
   } else if (dynamic_cast<KaxChapterProcess *>(e)) {
     KaxChapterProcess &p = *static_cast<KaxChapterProcess *>(e);
@@ -580,12 +592,12 @@ remove_entries(int64_t min_tc,
     KaxChapterTimeStart *cts = static_cast<KaxChapterTimeStart *>(atom->FindFirstElt(EBML_INFO(KaxChapterTimeStart), false));
 
     if (cts)
-      entries[i].start = uint64(*cts);
+      entries[i].start = cts->GetValue();
 
     KaxChapterTimeEnd *cte = static_cast<KaxChapterTimeEnd *>(atom->FindFirstElt(EBML_INFO(KaxChapterTimeEnd), false));
 
     if (cte)
-      entries[i].end = uint64(*cte);
+      entries[i].end = cte->GetValue();
   }
 
   // We can return if we don't have a single atom to work with.
@@ -634,18 +646,18 @@ remove_entries(int64_t min_tc,
     KaxChapterTimeEnd *cte   = static_cast<KaxChapterTimeEnd *>(atom->FindFirstElt(EBML_INFO(KaxChapterTimeEnd), false));
 
     if (entries[i].spans)
-      *static_cast<EbmlUInteger *>(cts) = min_tc;
+      cts->SetValue(min_tc);
 
-    *static_cast<EbmlUInteger *>(cts) = uint64(*cts) - offset;
+    cts->SetValue(cts->GetValue() - offset);
 
     if (cte) {
-      int64_t end_tc =  uint64(*cte);
+      int64_t end_tc = cte->GetValue();
 
       if ((max_tc >= 0) && (end_tc > max_tc))
         end_tc = max_tc;
       end_tc -= offset;
 
-      *static_cast<EbmlUInteger *>(cte) = end_tc;
+      cte->SetValue(end_tc);
     }
 
     EbmlMaster *m2 = dynamic_cast<EbmlMaster *>(m[i]);
@@ -740,9 +752,9 @@ merge_chapter_entries(EbmlMaster &master) {
     // Assign the start and end timecode to the chapter. Only assign an
     // end timecode if one was present in at least one of the merged
     // chapter atoms.
-    GetChildAs<KaxChapterTimeStart, EbmlUInteger>(*atom) = start_tc;
+    GetChild<KaxChapterTimeStart>(*atom).SetValue(start_tc);
     if (-1 != end_tc)
-      GetChildAs<KaxChapterTimeEnd, EbmlUInteger>(*atom) = end_tc;
+      GetChild<KaxChapterTimeEnd>(*atom).SetValue(end_tc);
   }
 
   // Recusively merge atoms.
@@ -843,7 +855,7 @@ find_edition_with_uid(KaxChapters &chapters,
       continue;
 
     KaxEditionUID *euid = FindChild<KaxEditionUID>(eentry);
-    if ((euid) && (uint64(*euid) == uid))
+    if (euid && (euid->GetValue() == uid))
       return eentry;
   }
 
@@ -883,7 +895,7 @@ find_chapter_with_uid(KaxChapters &chapters,
         continue;
 
       KaxChapterUID *cuid = FindChild<KaxChapterUID>(atom);
-      if ((cuid) && (uint64(*cuid) == uid))
+      if (cuid && (cuid->GetValue() == uid))
         return atom;
     }
   }
@@ -918,7 +930,7 @@ move_chapters_by_edition(KaxChapters &dst,
     KaxEditionEntry *ee_dst = nullptr;
     KaxEditionUID *euid_src = FindChild<KaxEditionUID>(m);
     if (euid_src)
-      ee_dst = find_edition_with_uid(dst, uint64(*euid_src));
+      ee_dst = find_edition_with_uid(dst, euid_src->GetValue());
 
     // No edition with the same UID found as the one we want to handle?
     // Then simply move the complete edition over.
@@ -967,10 +979,10 @@ adjust_chapter_timecodes(EbmlMaster &master,
     KaxChapterTimeEnd *end     = FindChild<KaxChapterTimeEnd>(atom);
 
     if (start)
-      *static_cast<EbmlUInteger *>(start) = std::max(int64_t(uint64(*start)) + offset, int64_t(0));
+      start->SetValue(std::max<int64_t>(static_cast<int64_t>(start->GetValue()) + offset, 0));
 
     if (end)
-      *static_cast<EbmlUInteger *>(end) = std::max(int64_t(uint64(*end)) + offset, int64_t(0));
+      end->SetValue(std::max<int64_t>(static_cast<int64_t>(end->GetValue()) + offset, 0));
   }
 
   for (master_idx = 0; master.ListSize() > master_idx; master_idx++) {
@@ -1029,7 +1041,7 @@ align_chapter_edition_uids(KaxChapters *chapters) {
     if (!edition_entry)
       continue;
 
-    GetChildAs<KaxEditionUID, EbmlUInteger>(*edition_entry) = s_shared_edition_uid;
+    GetChild<KaxEditionUID>(*edition_entry).SetValue(s_shared_edition_uid);
   }
 }
 
@@ -1053,7 +1065,7 @@ align_chapter_edition_uids(KaxChapters &reference,
     if (!ee_modify)
       return;
 
-    GetChildAs<KaxEditionUID, EbmlUInteger>(*ee_modify) = GetChildAs<KaxEditionUID, EbmlUInteger>(*ee_reference);
+    GetChild<KaxEditionUID>(*ee_modify).SetValue(GetChild<KaxEditionUID>(*ee_reference).GetValue());
     ++reference_idx;
     ++modify_idx;
   }
