@@ -77,11 +77,11 @@ command_line_args_from_environment() {
   std::vector<std::string> args;
 
   char const *value = getenv("MKVTOOLNIX_OPTIONS");
-  if (nullptr != value)
+  if (value)
     args = split(value, " ");
   else {
     value = getenv("MTX_OPTIONS");
-    if (nullptr != value)
+    if (value)
       args = split(value, " ");
   }
 
@@ -121,7 +121,7 @@ command_line_utf8(int argc,
       if (!strcmp(argv[i], "--command-line-charset")) {
         if ((i + 1) == argc)
           mxerror(Y("'--command-line-charset' is missing its argument.\n"));
-        cc_command_line = charset_converter_c::init(argv[i + 1] == nullptr ? "" : argv[i + 1]);
+        cc_command_line = charset_converter_c::init(!argv[i + 1] ? "" : argv[i + 1]);
         i++;
       } else
         args.push_back(cc_command_line->utf8(argv[i]));
@@ -141,7 +141,7 @@ command_line_utf8(int,
   int num_args     = 0;
   LPWSTR *arg_list = CommandLineToArgvW(GetCommandLineW(), &num_args);
 
-  if (nullptr == arg_list)
+  if (!arg_list)
     return args;
 
   int i;
@@ -181,20 +181,14 @@ std::string usage_text, version_info;
 bool
 handle_common_cli_args(std::vector<std::string> &args,
                        const std::string &redirect_output_short) {
-  size_t i                 = 0;
-  bool debug_options_found = false;
+  size_t i = 0;
 
   while (args.size() > i) {
     if (args[i] == "--debug") {
       if ((i + 1) == args.size())
         mxerror("Missing argument for '--debug'.\n");
 
-      if (!debug_options_found)
-        clear_debugging_requests();
-
       request_debugging(args[i + 1]);
-      debug_options_found = true;
-
       args.erase(args.begin() + i, args.begin() + i + 2);
 
     } else if (args[i] == "--engage") {
@@ -296,8 +290,16 @@ handle_common_cli_args(std::vector<std::string> &args,
       if (!rel.latest_source.valid)
         mxerror(boost::format(Y("The update information could not be retrieved from %1%.\n")) % MTX_VERSION_CHECK_URL);
 
-      mxinfo(boost::format("version_check_url=%1%\nrunning_version=%2%\navailable_version=%3%\ndownload_url=%4%\n")
-             % MTX_VERSION_CHECK_URL % rel.current_version.to_string() % rel.latest_source.to_string() % rel.source_download_url);
+      std::vector<std::string> keys;
+      brng::push_back(keys, rel.urls | badap::map_keys | badap::filtered([](std::string const &key) { return key != "general"; }));
+      brng::sort(keys);
+
+      std::string urls;
+      for (auto &key : keys)
+        urls += key + "_download_url=" + rel.urls[key] + "\n";
+
+      mxinfo(boost::format("version_check_url=%1%\nrunning_version=%2%\navailable_version=%3%\ndownload_url=%4%\n%5%")
+             % MTX_VERSION_CHECK_URL % rel.current_version.to_string() % rel.latest_source.to_string() % rel.urls["general"] % urls);
       mxexit(rel.current_version < rel.latest_source ? 1 : 0);
     }
 #endif  // defined(HAVE_CURL_EASY_H)
@@ -314,4 +316,3 @@ usage(int exit_code) {
   mxinfo(boost::format("%1%\n") % usage_text);
   mxexit(exit_code);
 }
-
