@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __MTX_COMMON_EBML_H
-#define __MTX_COMMON_EBML_H
+#ifndef MTX_COMMON_EBML_H
+#define MTX_COMMON_EBML_H
 
 #include "common/common_pch.h"
 
@@ -38,8 +38,8 @@ int kt_get_max_blockadd_id(KaxTrackEntry &track);
 std::string kt_get_language(KaxTrackEntry &track);
 
 int kt_get_a_channels(KaxTrackEntry &track);
-float kt_get_a_sfreq(KaxTrackEntry &track);
-float kt_get_a_osfreq(KaxTrackEntry &track);
+double kt_get_a_sfreq(KaxTrackEntry &track);
+double kt_get_a_osfreq(KaxTrackEntry &track);
 int kt_get_a_bps(KaxTrackEntry &track);
 
 int kt_get_v_pixel_width(KaxTrackEntry &track);
@@ -150,6 +150,19 @@ AddEmptyChild(EbmlMaster &master) {
   return *(static_cast<type *>(e));
 }
 
+template <typename T>
+T *
+FindChild(EbmlMaster const &m) {
+  return static_cast<T *>(m.FindFirstElt(EBML_INFO(T)));
+}
+
+template <typename T>
+T *
+FindChild(EbmlElement const &e) {
+  auto &m = dynamic_cast<EbmlMaster const &>(e);
+  return static_cast<T *>(m.FindFirstElt(EBML_INFO(T)));
+}
+
 template <typename A> A*
 FindChild(EbmlMaster const *m) {
   return static_cast<A *>(m->FindFirstElt(EBML_INFO(A)));
@@ -181,16 +194,6 @@ GetChild(EbmlMaster *m) {
   return GetChild<A>(*m);
 }
 
-template<typename A, typename B> B &
-GetChildAs(EbmlMaster &m) {
-  return GetChild<A>(m);
-}
-
-template<typename A, typename B> B &
-GetChildAs(EbmlMaster *m) {
-  return GetChild<A>(*m);
-}
-
 template <typename A>A &
 GetFirstOrNextChild(EbmlMaster &master,
                     A *previous_child) {
@@ -222,18 +225,75 @@ DeleteChildren(EbmlMaster &master) {
 }
 
 template<typename T>
-memory_cptr
-find_and_clone_binary(EbmlElement &parent) {
-  auto child = FindChild<T>(static_cast<EbmlMaster &>(parent));
-  if (child)
-    return memory_c::clone(child->GetBuffer(), child->GetSize());
-  return memory_cptr{};
+void
+FixMandatoryElement(EbmlMaster &master) {
+  auto &element = GetChild<T>(master);
+  element.SetValue(element.GetValue());
+}
+
+template<typename Tfirst,
+         typename Tsecond,
+         typename... Trest>
+void
+FixMandatoryElement(EbmlMaster &master) {
+  FixMandatoryElement<Tfirst>(master);
+  FixMandatoryElement<Tsecond, Trest...>(master);
+}
+
+template<typename... Trest>
+void
+FixMandatoryElement(EbmlMaster *master) {
+  if (!master)
+    return;
+  FixMandatoryElement<Trest...>(*master);
+}
+
+template<typename Telement,
+         typename Tvalue = decltype(Telement().GetValue())>
+Tvalue
+FindChildValue(EbmlMaster &master,
+               Tvalue const &default_value = Tvalue{}) {
+  auto child = FindChild<Telement>(master);
+  return child ? static_cast<Tvalue>(child->GetValue()) : default_value;
+}
+
+template<typename Telement,
+         typename Tvalue = decltype(Telement().GetValue())>
+Tvalue
+FindChildValue(EbmlMaster *master,
+               Tvalue const &default_value = Tvalue{}) {
+  return FindChildValue<Telement>(*master, default_value);
 }
 
 template<typename T>
 memory_cptr
-find_and_clone_binary(EbmlElement *parent) {
-  return find_and_clone_binary<T>(*parent);
+FindChildValue(EbmlMaster &master,
+               bool clone = true,
+               typename std::enable_if< std::is_base_of<EbmlBinary, T>::value >::type * = nullptr) {
+  auto child = FindChild<T>(master);
+  return !child ? memory_cptr()
+       : clone  ? memory_c::clone(child->GetBuffer(), child->GetSize())
+       :          memory_cptr(new memory_c(child->GetBuffer(), child->GetSize(), false));
+}
+
+template<typename T>
+memory_cptr
+FindChildValue(EbmlMaster *master,
+               bool clone = true,
+               typename std::enable_if< std::is_base_of<EbmlBinary, T>::value >::type * = nullptr) {
+  return FindChildValue<T>(*master, clone);
+}
+
+template<typename Telement>
+decltype(Telement().GetValue())
+GetChildValue(EbmlMaster &master) {
+  return GetChild<Telement>(master).GetValue();
+}
+
+template<typename Telement>
+decltype(Telement().GetValue())
+GetChildValue(EbmlMaster *master) {
+  return GetChild<Telement>(master).GetValue();
 }
 
 EbmlElement *empty_ebml_master(EbmlElement *e);
@@ -254,9 +314,9 @@ void fix_mandatory_elements(EbmlElement *master);
 template<typename A> void
 provide_default_for_child(EbmlMaster &master,
                           const UTFstring &default_value) {
-  EbmlUnicodeString &value = GetChildAs<A, EbmlUnicodeString>(master);
-  if (!static_cast<const UTFstring &>(value).length())
-    value = default_value;
+  A &value = GetChild<A>(master);
+  if (!value.GetValue().length())
+    value.SetValue(default_value);
 }
 
 template<typename A> void
@@ -268,4 +328,4 @@ provide_default_for_child(EbmlMaster *master,
 typedef std::shared_ptr<EbmlElement> ebml_element_cptr;
 typedef std::shared_ptr<EbmlMaster> ebml_master_cptr;
 
-#endif // __MTX_COMMON_EBML_H
+#endif // MTX_COMMON_EBML_H
