@@ -12,8 +12,8 @@
    Modified by Steve Lhomme <steve.lhomme@free.fr>.
 */
 
-#ifndef __MTX_COMMON_MATROSKA_H
-#define __MTX_COMMON_MATROSKA_H
+#ifndef MTX_COMMON_MATROSKA_H
+#define MTX_COMMON_MATROSKA_H
 
 // see http://www.matroska.org/technical/specs/codecid/index.html
 
@@ -135,4 +135,4 @@
 
 #define CHAPTER_PHYSEQUIV_INDEX        10
 
-#endif // __MTX_COMMON_MATROSKA_H
+#endif // MTX_COMMON_MATROSKA_H
