@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __MTX_COMMON_MEMORY_H
-#define __MTX_COMMON_MEMORY_H
+#ifndef MTX_COMMON_MEMORY_H
+#define MTX_COMMON_MEMORY_H
 
 #include "common/common_pch.h"
 
@@ -367,4 +367,4 @@ private:
 memory_cptr lace_memory_xiph(const std::vector<memory_cptr> &blocks);
 std::vector<memory_cptr> unlace_memory_xiph(memory_cptr &buffer);
 
-#endif  // __MTX_COMMON_MEMORY_H
+#endif  // MTX_COMMON_MEMORY_H
