@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_AVC_H
-#define __R_AVC_H
+#ifndef MTX_R_AVC_H
+#define MTX_R_AVC_H
 
 #include "common/common_pch.h"
 
@@ -28,7 +28,7 @@ private:
 public:
   avc_es_reader_c(const track_info_c &ti, const mm_io_cptr &in);
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("AVC/h.264") : "AVC/h.264";
   }
 
@@ -40,4 +40,4 @@ public:
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
-#endif // __R_AVC_H
+#endif // MTX_R_AVC_H
