@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_AVI_H
-#define __R_AVI_H
+#ifndef MTX_R_AVI_H
+#define MTX_R_AVI_H
 
 #include "common/common_pch.h"
 
@@ -83,7 +83,7 @@ public:
   avi_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~avi_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("AVI") : "AVI";
   }
 
@@ -131,4 +131,4 @@ protected:
   virtual void debug_dump_video_index();
 };
 
-#endif  // __R_AVI_H
+#endif  // MTX_R_AVI_H
