@@ -12,8 +12,8 @@
    Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_DTS_H
-#define __R_DTS_H
+#ifndef MTX_R_DTS_H
+#define MTX_R_DTS_H
 
 #include "common/common_pch.h"
 
@@ -36,7 +36,7 @@ public:
   dts_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~dts_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("DTS") : "DTS";
   }
 
@@ -51,4 +51,4 @@ protected:
   virtual int decode_buffer(size_t length);
 };
 
-#endif // __R_DTS_H
+#endif // MTX_R_DTS_H
