@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_FLAC_H
-#define __R_FLAC_H
+#ifndef MTX_R_FLAC_H
+#define MTX_R_FLAC_H
 
 #include "common/common_pch.h"
 
@@ -48,7 +48,7 @@ public:
   flac_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~flac_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("FLAC") : "FLAC";
   }
 
@@ -85,4 +85,4 @@ public:
 
 #endif // HAVE_FLAC_FORMAT_H
 
-#endif  // __R_FLAC_H
+#endif  // MTX_R_FLAC_H
