@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_FLV_H
-#define __R_FLV_H
+#ifndef MTX_R_FLV_H
+#define MTX_R_FLV_H
 
 #include "common/common_pch.h"
 
@@ -21,4 +21,4 @@ public:
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
-#endif // __R_FLV_H
+#endif // MTX_R_FLV_H
