@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_IVF_H
-#define __R_IVF_H
+#ifndef MTX_R_IVF_H
+#define MTX_R_IVF_H
 
 #include "common/common_pch.h"
 
@@ -28,7 +28,7 @@ public:
   ivf_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~ivf_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("IVF (VP8)") : "IVF (VP8)";
   }
 
@@ -40,4 +40,4 @@ public:
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
-#endif // __R_IVF_H
+#endif // MTX_R_IVF_H
