@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_MP3_H
-#define __R_MP3_H
+#ifndef MTX_R_MP3_H
+#define MTX_R_MP3_H
 
 #include "common/common_pch.h"
 
@@ -32,7 +32,7 @@ public:
   mp3_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~mp3_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("MP2/MP3") : "MP2/MP3";
   }
 
@@ -47,4 +47,4 @@ protected:
   static int find_valid_headers(mm_io_c &in, int64_t probe_range, int num_headers);
 };
 
-#endif  // __R_MP3_H
+#endif  // MTX_R_MP3_H
