@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_MPEG_ES_H
-#define __R_MPEG_ES_H
+#ifndef MTX_R_MPEG_ES_H
+#define MTX_R_MPEG_ES_H
 
 #include "common/common_pch.h"
 
@@ -30,7 +30,7 @@ public:
   mpeg_es_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~mpeg_es_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("MPEG video elementary stream") : "MPEG video elementary stream";
   }
 
@@ -44,4 +44,4 @@ public:
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
-#endif // __R_MPEG_ES_H
+#endif // MTX_R_MPEG_ES_H
