@@ -207,7 +207,7 @@ public:
   mpeg_ps_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~mpeg_ps_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("MPEG program stream") : "MPEG program stream";
   }
 
