@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_OGM_H
-#define __R_OGM_H
+#ifndef MTX_R_OGM_H
+#define MTX_R_OGM_H
 
 #include "common/common_pch.h"
 
@@ -102,7 +102,7 @@ public:
   ogm_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~ogm_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("Ogg/OGM") : "Ogg/OGM";
   }
 
@@ -128,4 +128,4 @@ private:
   virtual void handle_stream_comments();
 };
 
-#endif  // __R_OGM_H
+#endif  // MTX_R_OGM_H
