@@ -301,7 +301,7 @@ public:
   qtmp4_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~qtmp4_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("QuickTime/MP4") : "QuickTime/MP4";
   }
 
