@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_REAL_H
-#define __R_REAL_H
+#ifndef MTX_R_REAL_H
+#define MTX_R_REAL_H
 
 #include "common/common_pch.h"
 
@@ -95,7 +95,7 @@ public:
   real_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~real_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("RealMedia") : "RealMedia";
   }
 
@@ -128,4 +128,4 @@ protected:
   virtual void create_video_packetizer(real_demuxer_cptr dmx);
 };
 
-#endif  // __R_REAL_H
+#endif  // MTX_R_REAL_H
