@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_TRUEHD_H
-#define __R_TRUEHD_H
+#ifndef MTX_R_TRUEHD_H
+#define MTX_R_TRUEHD_H
 
 #include "common/common_pch.h"
 
@@ -32,7 +32,7 @@ public:
   truehd_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~truehd_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("TrueHD") : "TrueHD";
   }
 
@@ -47,4 +47,4 @@ protected:
   static bool find_valid_headers(mm_io_c &in, int64_t probe_range, int num_headers);
 };
 
-#endif // __R_TRUEHD_H
+#endif // MTX_R_TRUEHD_H
