@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_TTA_H
-#define __R_TTA_H
+#ifndef MTX_R_TTA_H
+#define MTX_R_TTA_H
 
 #include "common/common_pch.h"
 
@@ -34,7 +34,7 @@ public:
   tta_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~tta_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("TTA") : "TTA";
   }
 
@@ -46,4 +46,4 @@ public:
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
-#endif // __R_TTA_H
+#endif // MTX_R_TTA_H
