@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_USF_H
-#define __R_USF_H
+#ifndef MTX_R_USF_H
+#define MTX_R_USF_H
 
 #include "common/common_pch.h"
 
@@ -66,7 +66,7 @@ public:
   usf_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~usf_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("USF subtitles") : "USF subtitles";
   }
 
@@ -90,4 +90,4 @@ protected:
 
 };
 
-#endif  // __R_USF_H
+#endif  // MTX_R_USF_H
