@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __R_VC1_H
-#define __R_VC1_H
+#ifndef MTX_R_VC1_H
+#define MTX_R_VC1_H
 
 #include "common/common_pch.h"
 
@@ -30,7 +30,7 @@ private:
 public:
   vc1_es_reader_c(const track_info_c &ti, const mm_io_cptr &in);
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("VC1") : "VC1";
   }
 
@@ -42,4 +42,4 @@ public:
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
-#endif // __R_VC1_H
+#endif // MTX_R_VC1_H
