@@ -11,8 +11,8 @@
    Written by Steve Lhomme <steve.lhomme@free.fr>.
 */
 
-#ifndef __R_WAVPACK_H
-#define __R_WAVPACK_H
+#ifndef MTX_R_WAVPACK_H
+#define MTX_R_WAVPACK_H
 
 #include "common/common_pch.h"
 
@@ -33,7 +33,7 @@ public:
   wavpack_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~wavpack_reader_c();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("WAVPACK") : "WAVPACK";
   }
 
@@ -45,4 +45,4 @@ public:
   static int probe_file(mm_io_c *in, uint64_t size);
 };
 
-#endif // __R_WAVPACK_H
+#endif // MTX_R_WAVPACK_H
