@@ -25,6 +25,7 @@
 
 #include <matroska/KaxBlock.h>
 #include <matroska/KaxBlockData.h>
+#include <matroska/KaxCuesData.h>
 #include <matroska/KaxSeekHead.h>
 
 std::string
@@ -60,12 +61,17 @@ cluster_helper_c::cluster_helper_c()
   , m_first_video_keyframe_seen{}
   , m_out(nullptr)
   , m_current_split_point(m_split_points.begin())
+  , m_num_cue_points_postprocessed{}
   , m_discarding{false}
   , m_splitting_and_processed_fully{false}
+  , m_no_cue_duration{hack_engaged(ENGAGE_NO_CUE_DURATION)}
+  , m_no_cue_relative_position{hack_engaged(ENGAGE_NO_CUE_RELATIVE_POSITION)}
   , m_debug_splitting{debugging_requested("cluster_helper|splitting")}
   , m_debug_packets{  debugging_requested("cluster_helper|cluster_helper_packets")}
   , m_debug_duration{ debugging_requested("cluster_helper|cluster_helper_duration")}
   , m_debug_rendering{debugging_requested("cluster_helper|cluster_helper_rendering")}
+  , m_debug_cue_duration{debugging_requested("cluster_helper|cluster_helper_cue_duration")}
+  , m_debug_cue_relative_position{debugging_requested("cluster_helper|cluster_helper_cue_relative_position")}
 {
 }
 
@@ -325,6 +331,8 @@ int
 cluster_helper_c::render() {
   std::vector<render_groups_cptr> render_groups;
 
+  m_id_timecode_duration_map.clear();
+
   bool use_simpleblock    = !hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS);
 
   LacingType lacing_type  = hack_engaged(ENGAGE_LACING_XIPH) ? LACING_XIPH : hack_engaged(ENGAGE_LACING_EBML) ? LACING_EBML : LACING_AUTO;
@@ -431,10 +439,12 @@ cluster_helper_c::render() {
     render_group->m_durations.push_back(pack->get_unmodified_duration());
     render_group->m_duration_mandatory |= pack->duration_mandatory;
 
+    m_id_timecode_duration_map[ id_timecode_t{ source->get_track_num(), pack->assigned_timecode - timecode_offset } ] = pack->get_duration();
+
     if (new_block_group) {
       // Set the reference priority if it was wanted.
       if ((0 < pack->ref_priority) && new_block_group->replace_simple_by_group())
-        GetChildAs<KaxReferencePriority, EbmlUInteger>(*new_block_group) = pack->ref_priority;
+        GetChild<KaxReferencePriority>(*new_block_group).SetValue(pack->ref_priority);
 
       // Handle BlockAdditions if needed
       if (!pack->data_adds.empty() && new_block_group->ReplaceSimpleByGroup()) {
@@ -442,9 +452,8 @@ cluster_helper_c::render() {
 
         size_t data_add_idx;
         for (data_add_idx = 0; pack->data_adds.size() > data_add_idx; ++data_add_idx) {
-          KaxBlockMore &block_more                                           = AddEmptyChild<KaxBlockMore>(additions);
-          GetChildAs<KaxBlockAddID, EbmlUInteger>(block_more) = data_add_idx + 1;
-
+          auto &block_more = AddEmptyChild<KaxBlockMore>(additions);
+          GetChild<KaxBlockAddID     >(block_more).SetValue(data_add_idx + 1);
           GetChild<KaxBlockAdditional>(block_more).CopyBuffer((binary *)pack->data_adds[data_add_idx]->get_buffer(), pack->data_adds[data_add_idx]->get_size());
         }
       }
@@ -455,31 +464,8 @@ cluster_helper_c::render() {
     if (!new_block_group)
       new_block_group = previous_block_group;
 
-    else if (g_write_cues && (!added_to_cues || has_codec_state)) {
-      // Update the cues (index table) either if cue entries for
-      // I frames were requested and this is an I frame...
-      if ((   (CUE_STRATEGY_IFRAMES == source->get_cue_creation())
-           && pack->is_key_frame())
-          // ... or if a codec state change is present ...
-          || has_codec_state
-          // ... or if the user requested entries for all frames ...
-          || (CUE_STRATEGY_ALL == source->get_cue_creation())
-          // ... or if this is an audio track, there is no video track and the
-          // last cue entry was created more than 2s ago.
-          || (   (CUE_STRATEGY_SPARSE == source->get_cue_creation())
-              && (track_audio         == source->get_track_type())
-              && !g_video_packetizer
-              && (   (0 > source->get_last_cue_timecode())
-                  || ((pack->assigned_timecode - source->get_last_cue_timecode()) >= 2000000000)))) {
-
-        g_kax_cues->AddBlockBlob(*new_block_group);
-        source->set_last_cue_timecode(pack->assigned_timecode);
-
-        m_num_cue_elements++;
-        g_cue_writing_requested = 1;
-        added_to_cues           = true;
-      }
-    }
+    else if (g_write_cues && (!added_to_cues || has_codec_state))
+      added_to_cues = add_to_cues_maybe(pack, *new_block_group);
 
     pack->group = new_block_group;
   }
@@ -500,6 +486,8 @@ cluster_helper_c::render() {
         g_kax_sh_cues->IndexThis(*m_cluster, *g_kax_segment);
 
       m_previous_cluster_tc = m_cluster->GlobalTimecode();
+
+      postprocess_cues();
     } else
       m_previous_cluster_tc = -1;
   }
@@ -512,6 +500,126 @@ cluster_helper_c::render() {
   return 1;
 }
 
+bool
+cluster_helper_c::add_to_cues_maybe(packet_cptr &pack,
+                                    kax_block_blob_c &block_group) {
+  auto &source  = *pack->source;
+  auto strategy = source.get_cue_creation();
+
+  // Update the cues (index table) either if cue entries for I frames were requested and this is an I frame...
+  bool add = (CUE_STRATEGY_IFRAMES == strategy) && pack->is_key_frame();
+
+  // ... or if a codec state change is present ...
+  add = add || !!pack->codec_state;
+
+  // ... or if the user requested entries for all frames ...
+  add = add || (CUE_STRATEGY_ALL == strategy);
+
+  // ... or if this is an audio track, there is no video track and the
+  // last cue entry was created more than 2s ago.
+  add = add || (   (CUE_STRATEGY_SPARSE == strategy)
+                && (track_audio         == source.get_track_type())
+                && !g_video_packetizer
+                && (   (0 > source.get_last_cue_timecode())
+                    || ((pack->assigned_timecode - source.get_last_cue_timecode()) >= 2000000000)));
+
+  if (!add)
+    return false;
+
+  g_kax_cues->AddBlockBlob(block_group);
+  source.set_last_cue_timecode(pack->assigned_timecode);
+
+  ++m_num_cue_elements;
+  g_cue_writing_requested = 1;
+
+  return true;
+}
+
+std::map<id_timecode_t, int64_t>
+cluster_helper_c::calculate_block_positions()
+  const {
+
+  std::map<id_timecode_t, int64_t> positions;
+
+  for (auto child : *m_cluster) {
+    auto simple_block = dynamic_cast<KaxSimpleBlock *>(child);
+    if (simple_block) {
+      simple_block->SetParent(*m_cluster);
+      positions[ id_timecode_t{ simple_block->TrackNum(), simple_block->GlobalTimecode() } ] = simple_block->GetElementPosition();
+      continue;
+    }
+
+    auto block_group = dynamic_cast<KaxBlockGroup *>(child);
+    if (!block_group)
+      continue;
+
+    auto block = FindChild<KaxBlock>(block_group);
+    if (!block)
+      continue;
+
+    block->SetParent(*m_cluster);
+    positions[ id_timecode_t{ block->TrackNum(), block->GlobalTimecode() } ] = block->GetElementPosition();
+  }
+
+  return positions;
+}
+
+void
+cluster_helper_c::postprocess_cues() {
+  if (!g_kax_cues || !m_cluster)
+    return;
+
+  if (m_no_cue_duration && m_no_cue_relative_position)
+    return;
+
+  auto cluster_data_start_pos = m_cluster->GetElementPosition() + m_cluster->HeadSize();
+  auto block_positions        = calculate_block_positions();
+
+  auto &children = g_kax_cues->GetElementList();
+  for (auto size = children.size(); m_num_cue_points_postprocessed < size; ++m_num_cue_points_postprocessed) {
+    auto point = dynamic_cast<KaxCuePoint *>(children[m_num_cue_points_postprocessed]);
+    if (!point)
+      continue;
+
+    auto time = static_cast<int64_t>(GetChild<KaxCueTime>(point).GetValue() * g_timecode_scale);
+
+    for (auto child : *point) {
+      auto positions = dynamic_cast<KaxCueTrackPositions *>(child);
+      if (!positions)
+        continue;
+
+      auto track_num = GetChild<KaxCueTrack>(positions).GetValue();
+
+      // Set CueRelativePosition for all cues.
+      if (!m_no_cue_relative_position) {
+        auto position_itr = block_positions.find({ track_num, time });
+        auto position     = block_positions.end() != position_itr ? std::max<int64_t>(position_itr->second, cluster_data_start_pos) : 0ll;
+        if (position)
+          GetChild<KaxCueRelativePosition>(positions).SetValue(position - cluster_data_start_pos);
+
+        mxdebug_if(m_debug_cue_relative_position,
+                   boost::format("cue_relative_position: looking for <%1%:%2%>: cluster_data_start_pos %3% position %4%\n")
+                   % track_num % time % cluster_data_start_pos % position);
+      }
+
+      // Set CueDuration if the packetizer wants them.
+      if (m_no_cue_duration)
+        continue;
+
+      auto duration_itr = m_id_timecode_duration_map.find({ track_num, time });
+      auto ptzr         = g_packetizers_by_track_num[track_num];
+
+      if (!ptzr || !ptzr->wants_cue_duration())
+        continue;
+
+      if ((m_id_timecode_duration_map.end() != duration_itr) && (0 < duration_itr->second))
+        GetChild<KaxCueDuration>(positions).SetValue(RND_TIMECODE_SCALE(duration_itr->second) / g_timecode_scale);
+
+      mxdebug_if(m_debug_cue_duration, boost::format("cue_duration: looking for <%1%:%2%>: %3%\n") % track_num % time % (duration_itr == m_id_timecode_duration_map.end() ? static_cast<int64_t>(-1) : duration_itr->second));
+    }
+  }
+}
+
 int64_t
 cluster_helper_c::get_duration() {
   mxdebug_if(m_debug_duration,
