@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __CLUSTER_HELPER_C
-#define __CLUSTER_HELPER_C
+#ifndef MTX_CLUSTER_HELPER_C
+#define MTX_CLUSTER_HELPER_C
 
 #include "common/common_pch.h"
 
@@ -76,6 +76,8 @@ struct split_point_t {
   std::string str() const;
 };
 
+typedef std::pair<int64_t, int64_t> id_timecode_t;
+
 class cluster_helper_c {
 private:
   kax_cluster_c *m_cluster;
@@ -92,8 +94,14 @@ private:
   std::vector<split_point_t> m_split_points;
   std::vector<split_point_t>::iterator m_current_split_point;
 
+  std::map<id_timecode_t, int64_t> m_id_timecode_duration_map;
+  size_t m_num_cue_points_postprocessed;
+
   bool m_discarding, m_splitting_and_processed_fully;
-  bool m_debug_splitting, m_debug_packets, m_debug_duration, m_debug_rendering;
+
+  bool m_no_cue_duration, m_no_cue_relative_position;
+
+  bool m_debug_splitting, m_debug_packets, m_debug_duration, m_debug_rendering, m_debug_cue_duration, m_debug_cue_relative_position;
 
 public:
   cluster_helper_c();
@@ -146,8 +154,12 @@ private:
   void render_after_adding_if_necessary(packet_cptr &packet);
   void split_if_necessary(packet_cptr &packet);
   void split(packet_cptr &packet);
+
+  bool add_to_cues_maybe(packet_cptr &pack, kax_block_blob_c &block_group);
+  void postprocess_cues();
+  std::map<id_timecode_t, int64_t> calculate_block_positions() const;
 };
 
 extern cluster_helper_c *g_cluster_helper;
 
-#endif // __CLUSTER_HELPER_C
+#endif // MTX_CLUSTER_HELPER_C
