@@ -59,6 +59,7 @@
 #include <matroska/KaxVersion.h>
 
 #include "common/chapters/chapters.h"
+#include "common/debugging.h"
 #include "common/ebml.h"
 #include "common/fs_sys_helpers.h"
 #include "common/hacks.h"
@@ -128,6 +129,7 @@ std::vector<filelist_t> g_files;
 std::vector<attachment_t> g_attachments;
 std::vector<track_order_t> g_track_order;
 std::vector<append_spec_t> g_append_mapping;
+std::unordered_map<int64_t, generic_packetizer_c *> g_packetizers_by_track_num;
 family_uids_c g_segfamily_uids;
 
 int64_t g_attachment_sizes_first            = 0;
@@ -188,6 +190,7 @@ int g_split_max_num_files                   = 65535;
 
 append_mode_e g_append_mode                 = APPEND_MODE_FILE_BASED;
 bool s_appending_files                      = false;
+bool s_debug_appending                      = false;
 
 bool g_stereo_mode_used                     = false;
 
@@ -277,7 +280,7 @@ sighandler(int /* signum */) {
   // Now re-render the kax_duration and fill in the biggest timecode
   // as the file's duration.
   s_out->save_pos(s_kax_duration->GetElementPosition());
-  *(static_cast<EbmlFloat *>(s_kax_duration)) = irnd((double)g_cluster_helper->get_duration() / (double)((int64_t)g_timecode_scale));
+  s_kax_duration->SetValue(irnd(static_cast<double>(g_cluster_helper->get_duration()) / static_cast<double>(g_timecode_scale)));
   s_kax_duration->Render(*s_out);
   s_out->restore_pos();
   mxinfo(Y(" done\n"));
@@ -623,7 +626,7 @@ set_timecode_scale() {
 
   bool debug = debugging_requested("set_timecode_scale|timecode_scale");
   mxdebug_if(debug,
-             boost::format("scale mode: %1% audio present: %2% video present: %3% highest sample rate: %4%\n")
+             boost::format("timecode_scale: %1% audio present: %2% video present: %3% highest sample rate: %4%\n")
              % (  TIMECODE_SCALE_MODE_NORMAL == g_timecode_scale_mode ? "normal"
                 : TIMECODE_SCALE_MODE_FIXED  == g_timecode_scale_mode ? "fixed"
                 : TIMECODE_SCALE_MODE_AUTO   == g_timecode_scale_mode ? "auto"
@@ -637,12 +640,12 @@ set_timecode_scale() {
           || (TIMECODE_SCALE_MODE_AUTO == g_timecode_scale_mode)))
     g_timecode_scale = static_cast<int64_t>(1000000000.0 / highest_sample_rate - 1.0);
 
-  g_max_ns_per_cluster                                    = std::min((int64_t)(32700 * g_timecode_scale), g_max_ns_per_cluster);
-  GetChildAs<KaxTimecodeScale, EbmlUInteger>(s_kax_infos) = (int64_t)g_timecode_scale;
+  g_max_ns_per_cluster = std::min<int64_t>(32700 * g_timecode_scale, g_max_ns_per_cluster);
+  GetChild<KaxTimecodeScale>(s_kax_infos).SetValue(g_timecode_scale);
 
-  g_kax_cues->SetGlobalTimecodeScale((int64_t)g_timecode_scale);
+  g_kax_cues->SetGlobalTimecodeScale(g_timecode_scale);
 
-  mxdebug_if(debug, boost::format("timecode scale: %1% max ns per cluster: %2%\n") % g_timecode_scale % g_max_ns_per_cluster);
+  mxdebug_if(debug, boost::format("timecode_scale: %1% max ns per cluster: %2%\n") % g_timecode_scale % g_max_ns_per_cluster);
 }
 
 static void
@@ -650,12 +653,13 @@ render_ebml_head(mm_io_c *out) {
   if (!s_head)
     s_head = new EbmlHead;
 
-  unsigned int doc_type_read_version                     = hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS) ? 1 : 2;
+  bool v4_features = !hack_engaged(ENGAGE_NO_CUE_DURATION) || !hack_engaged(ENGAGE_NO_CUE_RELATIVE_POSITION);
+  bool v3_features = g_stereo_mode_used;
+  bool v2_features = !hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS);
 
-  GetChildAs<EDocType, EbmlString>(*s_head)              = outputting_webm() ? "webm" : "matroska";
-
-  GetChildAs<EDocTypeVersion,     EbmlUInteger>(*s_head) = g_stereo_mode_used ? 3 : doc_type_read_version;
-  GetChildAs<EDocTypeReadVersion, EbmlUInteger>(*s_head) = doc_type_read_version;
+  GetChild<EDocType           >(*s_head).SetValue(outputting_webm() ? "webm" : "matroska");
+  GetChild<EDocTypeVersion    >(*s_head).SetValue(v4_features ? 4 : v3_features ? 3 : v2_features ? 2 : 1);
+  GetChild<EDocTypeReadVersion>(*s_head).SetValue(v2_features ? 2 : 1);
 
   s_head->Render(*out, true);
 }
@@ -686,23 +690,22 @@ render_headers(mm_io_c *out) {
     else
       s_kax_duration = new KaxMyDuration(EbmlFloat::FLOAT_32);
 
-    *(static_cast<EbmlFloat *>(s_kax_duration)) = 0.0;
+    s_kax_duration->SetValue(0.0);
     s_kax_infos->PushElement(*s_kax_duration);
 
     if (!hack_engaged(ENGAGE_NO_VARIABLE_DATA)) {
-      std::string muxing_app                                    = std::string("libebml v") + EbmlCodeVersion + std::string(" + libmatroska v") + KaxCodeVersion;
-      GetChildAs<KaxMuxingApp, EbmlUnicodeString>(s_kax_infos)  = cstrutf8_to_UTFstring(muxing_app);
-      GetChildAs<KaxWritingApp, EbmlUnicodeString>(s_kax_infos) = cstrutf8_to_UTFstring(get_version_info("mkvmerge", static_cast<version_info_flags_e>(vif_full | vif_untranslated)));
-      GetChild<KaxDateUTC>(*s_kax_infos).SetEpochDate(time(nullptr));
+      GetChild<KaxMuxingApp >(s_kax_infos).SetValue(cstrutf8_to_UTFstring(std::string("libebml v") + EbmlCodeVersion + std::string(" + libmatroska v") + KaxCodeVersion));
+      GetChild<KaxWritingApp>(s_kax_infos).SetValue(cstrutf8_to_UTFstring(get_version_info("mkvmerge", static_cast<version_info_flags_e>(vif_full | vif_untranslated))));
+      GetChild<KaxDateUTC   >(s_kax_infos).SetEpochDate(time(nullptr));
 
     } else {
-      GetChildAs<KaxMuxingApp, EbmlUnicodeString>(s_kax_infos)  = cstrutf8_to_UTFstring("no_variable_data");
-      GetChildAs<KaxWritingApp, EbmlUnicodeString>(s_kax_infos) = cstrutf8_to_UTFstring("no_variable_data");
-      GetChild<KaxDateUTC>(*s_kax_infos).SetEpochDate(0);
+      GetChild<KaxMuxingApp >(s_kax_infos).SetValue(cstrutf8_to_UTFstring("no_variable_data"));
+      GetChild<KaxWritingApp>(s_kax_infos).SetValue(cstrutf8_to_UTFstring("no_variable_data"));
+      GetChild<KaxDateUTC   >(s_kax_infos).SetEpochDate(0);
     }
 
     if (!g_segment_title.empty())
-      GetChildAs<KaxTitle, EbmlUnicodeString>(s_kax_infos)      = cstrutf8_to_UTFstring(g_segment_title.c_str());
+      GetChild<KaxTitle>(s_kax_infos).SetValue(cstrutf8_to_UTFstring(g_segment_title.c_str()));
 
     bool first_file = (1 == g_file_num);
 
@@ -773,13 +776,13 @@ render_headers(mm_io_c *out) {
       }
 
       if (!g_segment_filename.empty())
-        GetChildAs<KaxSegmentFilename, EbmlUnicodeString>(*s_kax_infos) = cstrutf8_to_UTFstring(g_segment_filename);
+        GetChild<KaxSegmentFilename>(*s_kax_infos).SetValue(cstrutf8_to_UTFstring(g_segment_filename));
 
       if (!g_next_segment_filename.empty())
-        GetChildAs<KaxNextFilename, EbmlUnicodeString>(*s_kax_infos)    = cstrutf8_to_UTFstring(g_next_segment_filename);
+        GetChild<KaxNextFilename>(*s_kax_infos).SetValue(cstrutf8_to_UTFstring(g_next_segment_filename));
 
       if (!g_previous_segment_filename.empty())
-        GetChildAs<KaxPrevFilename, EbmlUnicodeString>(*s_kax_infos)    = cstrutf8_to_UTFstring(g_previous_segment_filename);
+        GetChild<KaxPrevFilename>(*s_kax_infos).SetValue(cstrutf8_to_UTFstring(g_previous_segment_filename));
 
       g_segment_filename.clear();
       g_next_segment_filename.clear();
@@ -883,24 +886,21 @@ render_attachments(IOCallback *out) {
       kax_a = !kax_a ? &GetChild<KaxAttached>(*s_kax_as) : &GetNextChild<KaxAttached>(*s_kax_as, *kax_a);
 
       if (attch.description != "")
-        GetChildAs<KaxFileDescription, EbmlUnicodeString>(kax_a) = cstrutf8_to_UTFstring(attch.description);
+        GetChild<KaxFileDescription>(kax_a).SetValue(cstrutf8_to_UTFstring(attch.description));
 
       if (attch.mime_type != "")
-        GetChildAs<KaxMimeType, EbmlString>(kax_a)               = attch.mime_type;
+        GetChild<KaxMimeType>(kax_a).SetValue(attch.mime_type);
 
       std::string name;
       if (attch.stored_name == "") {
         int path_sep_idx = attch.name.rfind(PATHSEP);
-        if (-1 != path_sep_idx)
-          name = attch.name.substr(path_sep_idx + 1);
-        else
-          name = attch.name;
+        name             = -1 != path_sep_idx ? attch.name.substr(path_sep_idx + 1) : attch.name;
 
       } else
         name = attch.stored_name;
 
-      GetChildAs<KaxFileName, EbmlUnicodeString>(kax_a) = cstrutf8_to_UTFstring(name);
-      GetChildAs<KaxFileUID, EbmlUInteger>(kax_a)       = attch.id;
+      GetChild<KaxFileName>(kax_a).SetValue(cstrutf8_to_UTFstring(name));
+      GetChild<KaxFileUID >(kax_a).SetValue(attch.id);
 
       GetChild<KaxFileData>(*kax_a).CopyBuffer(attch.data->get_buffer(), attch.data->get_size());
     }
@@ -1387,8 +1387,8 @@ add_tags_from_cue_chapters() {
   if (!found)
     tuid = ptzrs_in_header_order[0]->get_uid();
 
-  for (i = 0; g_tags_from_cue_chapters->ListSize() > i; ++i)
-    GetChildAs<KaxTagTrackUID, EbmlUInteger>(GetChild<KaxTagTargets>(*static_cast<KaxTag *>((*g_tags_from_cue_chapters)[i]))) = tuid;
+  for (auto tag : *g_tags_from_cue_chapters)
+    GetChild<KaxTagTrackUID>(GetChild<KaxTagTargets>(*static_cast<KaxTag *>(tag))).SetValue(tuid);
 
   if (!s_kax_tags)
     s_kax_tags = g_tags_from_cue_chapters;
@@ -1473,7 +1473,7 @@ prepare_tags_for_rendering() {
 */
 void
 create_next_output_file() {
-  mxdebug_if(debugging_requested("splitting"), boost::format("Create next output file splitting? %1% discarding? %2%\n") % g_cluster_helper->splitting() % g_cluster_helper->discarding());
+  mxdebug_if(debugging_requested("splitting"), boost::format("splitting: Create next output file; splitting? %1% discarding? %2%\n") % g_cluster_helper->splitting() % g_cluster_helper->discarding());
 
   auto this_outfile   = g_cluster_helper->split_mode_produces_many_files() ? create_output_name() : g_outfile;
 
@@ -1539,7 +1539,7 @@ finish_file(bool last_file) {
          % g_cluster_helper->get_duration() % g_timecode_scale
          % irnd((double)g_cluster_helper->get_duration() / (double)((int64_t)g_timecode_scale)));
 
-  *(static_cast<EbmlFloat *>(s_kax_duration)) = irnd((double)g_cluster_helper->get_duration() / (double)((int64_t)g_timecode_scale));
+  s_kax_duration->SetValue(irnd(static_cast<double>(g_cluster_helper->get_duration()) / static_cast<double>(g_timecode_scale)));
   s_kax_duration->Render(*s_out);
 
   // If splitting is active and this is the last part then handle the
@@ -1785,6 +1785,39 @@ append_track(packetizer_t &ptzr,
     }
   }
 
+  if (s_debug_appending) {
+    mxdebug(boost::format("appending: reader m_max_timecode_seen %1% and ptzr to append is %2% ptzr appended to is %3% src_file.appending %4% src_file.appended_to %5% dst_file.appending %6% dst_file.appended_to %7%\n")
+            % dst_file.reader->m_max_timecode_seen % static_cast<void *>(*gptzr) % static_cast<void *>(ptzr.packetizer) % src_file.appending % src_file.appended_to % dst_file.appending % dst_file.appended_to);
+    for (auto &rep_ptzr : dst_file.reader->m_reader_packetizers)
+      mxdebug(boost::format("  ptzr @ %1% connected_to %2% max_timecode_seen %3%\n") % static_cast<void *>(rep_ptzr) % rep_ptzr->m_connected_to % rep_ptzr->m_max_timecode_seen);
+  }
+
+  // In rare cases (e.g. empty tracks) a whole file could be skipped
+  // without having gotten a single packet through to the timecoding
+  // code. Therefore the reader's m_max_timecode_seen field would
+  // still be 0. Therefore we must ensure that each packetizer from a
+  // file we're trying to use m_max_timecode_seen from has already
+  // been connected fully. The very first file in a chain (meaning
+  // files that are not in "appending to other file mode",
+  // filelist_t.appending == false) would be OK as well.
+  if (dst_file.appending) {
+    std::list<generic_packetizer_c *> not_connected_ptzrs;
+    for (auto &check_ptzr : dst_file.reader->m_reader_packetizers)
+      if ((check_ptzr != ptzr.packetizer) && (2 != check_ptzr->m_connected_to))
+        not_connected_ptzrs.push_back(check_ptzr);
+
+    if (s_debug_appending) {
+      std::string result;
+      for (auto &out_ptzr : not_connected_ptzrs)
+        result += (boost::format(" %1%") % static_cast<void *>(out_ptzr)).str();
+
+      mxdebug(boost::format("appending: check for connection on dst file's packetizers; these are not connected: %1%\n") % result);
+    }
+
+    if (!not_connected_ptzrs.empty())
+      return;
+  }
+
   mxinfo(boost::format(Y("Appending track %1% from file no. %2% ('%3%') to track %4% from file no. %5% ('%6%').\n"))
          % (*gptzr)->m_ti.m_id % amap.src_file_id % (*gptzr)->m_ti.m_fname % ptzr.packetizer->m_ti.m_id % amap.dst_file_id % ptzr.packetizer->m_ti.m_fname);
 
@@ -1852,14 +1885,12 @@ append_track(packetizer_t &ptzr,
   }
 
   if ((APPEND_MODE_FILE_BASED == g_append_mode) || (ptzr.packetizer->get_track_type() == track_subtitle)) {
-    mxverb(2, boost::format("append_track: new timecode_adjustment for append_mode == FILE_BASED or subtitle track: %1% for %2%\n")
-           % format_timecode(timecode_adjustment) % ptzr.packetizer->m_ti.m_id);
+    mxdebug_if(s_debug_appending, boost::format("appending: new timecode_adjustment for append_mode == FILE_BASED or subtitle track: %1% for %2%\n") % format_timecode(timecode_adjustment) % ptzr.packetizer->m_ti.m_id);
     // The actual connection.
     ptzr.packetizer->connect(old_packetizer, timecode_adjustment);
 
   } else {
-    mxverb(2, boost::format("append_track: new timecode_adjustment for append_mode == TRACK_BASED and NON subtitle track: %1% for %2%\n")
-           % format_timecode(timecode_adjustment) % ptzr.packetizer->m_ti.m_id);
+    mxdebug_if(s_debug_appending, boost::format("appending: new timecode_adjustment for append_mode == TRACK_BASED and NON subtitle track: %1% for %2%\n") % format_timecode(timecode_adjustment) % ptzr.packetizer->m_ti.m_id);
     // The actual connection.
     ptzr.packetizer->connect(old_packetizer);
   }
@@ -2021,6 +2052,8 @@ discard_queued_packets() {
 */
 void
 main_loop() {
+  s_debug_appending = debugging_requested("append|appending");
+
   // Let's go!
   while (1) {
     debug_run_main_loop_hooks();
