@@ -12,12 +12,13 @@
    Modified by Steve Lhomme <steve.lhomme@free.fr>.
 */
 
-#ifndef __OUTPUT_CONTROL_H
-#define __OUTPUT_CONTROL_H
+#ifndef MTX_OUTPUT_CONTROL_H
+#define MTX_OUTPUT_CONTROL_H
 
 #include "common/common_pch.h"
 
 #include <deque>
+#include <unordered_map>
 
 #include "common/bitvalue.h"
 #include "common/file_types.h"
@@ -159,6 +160,7 @@ extern std::vector<filelist_t> g_files;
 extern std::vector<attachment_t> g_attachments;
 extern std::vector<track_order_t> g_track_order;
 extern std::vector<append_spec_t> g_append_mapping;
+extern std::unordered_map<int64_t, generic_packetizer_c *> g_packetizers_by_track_num;
 
 extern std::string g_outfile;
 
@@ -237,4 +239,4 @@ int64_t add_attachment(attachment_t attachment);
 void sighandler(int signum);
 #endif
 
-#endif // __OUTPUT_CONTROL_H
+#endif // MTX_OUTPUT_CONTROL_H
