@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __MMG_OPTIONS_MMG_H
-#define __MMG_OPTIONS_MMG_H
+#ifndef MTX_MMG_OPTIONS_MMG_H
+#define MTX_MMG_OPTIONS_MMG_H
 
 #include "common/common_pch.h"
 
@@ -85,4 +85,4 @@ public:
   virtual wxString get_title();
 };
 
-#endif // __MMG_OPTIONS_MMG_H
+#endif // MTX_MMG_OPTIONS_MMG_H
