@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_AAC_H
-#define __P_AAC_H
+#ifndef MTX_P_AAC_H
+#define MTX_P_AAC_H
 
 #include "common/common_pch.h"
 
@@ -38,7 +38,7 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("AAC") : "AAC";
   }
 
@@ -49,4 +49,4 @@ private:
   virtual int process_headerless(packet_cptr packet);
 };
 
-#endif // __P_AAC_H
+#endif // MTX_P_AAC_H
