@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_AC3_H
-#define __P_AC3_H
+#ifndef MTX_P_AC3_H
+#define MTX_P_AC3_H
 
 #include "common/common_pch.h"
 
@@ -37,7 +37,7 @@ public:
   virtual void flush_packets();
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("AC3") : "AC3";
   }
 
@@ -63,4 +63,4 @@ protected:
   virtual void add_to_buffer(unsigned char *const buf, int size);
 };
 
-#endif // __P_AC3_H
+#endif // MTX_P_AC3_H
