@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_DIRAC_H
-#define __P_DIRAC_H
+#ifndef MTX_P_DIRAC_H
+#define MTX_P_DIRAC_H
 
 #include "common/common_pch.h"
 
@@ -34,7 +34,7 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("Dirac") : "Dirac";
   };
 
@@ -46,4 +46,4 @@ protected:
   virtual void headers_found();
 };
 
-#endif // __P_DIRAC_H
+#endif // MTX_P_DIRAC_H
