@@ -12,8 +12,8 @@
    Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_DTS_H
-#define __P_DTS_H
+#ifndef MTX_P_DTS_H
+#define MTX_P_DTS_H
 
 #include "common/common_pch.h"
 
@@ -41,7 +41,7 @@ public:
   virtual void set_skipping_is_normal(bool skipping_is_normal) {
     m_skipping_is_normal = skipping_is_normal;
   }
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("DTS") : "DTS";
   }
 
@@ -55,4 +55,4 @@ private:
   virtual void process_available_packets(bool flushing);
 };
 
-#endif // __P_DTS_H
+#endif // MTX_P_DTS_H
