@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_FLAC_H
-#define __P_FLAC_H
+#ifndef MTX_P_FLAC_H
+#define MTX_P_FLAC_H
 
 #include "common/common_pch.h"
 
@@ -35,7 +35,7 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("FLAC") : "FLAC";
   }
 
@@ -43,4 +43,4 @@ public:
 };
 
 #endif  // HAVE_FLAC_STREAM_DECODER_H
-#endif  // __P_FLAC_H
+#endif  // MTX_P_FLAC_H
