@@ -12,8 +12,8 @@
    Adapted from code by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_KATE_H
-#define __P_KATE_H
+#ifndef MTX_P_KATE_H
+#define MTX_P_KATE_H
 
 #include "common/common_pch.h"
 
@@ -36,10 +36,10 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("Kate") : "Kate";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
-#endif  // __P_KATE_H
+#endif  // MTX_P_KATE_H
