@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_MP3_H
-#define __P_MP3_H
+#ifndef MTX_P_MP3_H
+#define MTX_P_MP3_H
 
 #include "common/common_pch.h"
 
@@ -38,7 +38,7 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("MP3") : "MP3";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
@@ -49,4 +49,4 @@ private:
   virtual void handle_garbage(int64_t bytes);
 };
 
-#endif // __P_MP3_H
+#endif // MTX_P_MP3_H
