@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_MPEG4_P10_H
-#define __P_MPEG4_P10_H
+#ifndef MTX_P_MPEG4_P10_H
+#define MTX_P_MPEG4_P10_H
 
 #include "common/common_pch.h"
 
@@ -30,7 +30,7 @@ public:
 
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("AVC/h.264") : "AVC/h.264";
   }
 
@@ -40,4 +40,4 @@ protected:
   virtual void change_nalu_size_len(packet_cptr packet);
 };
 
-#endif  // __P_MPEG4_P10_H
+#endif  // MTX_P_MPEG4_P10_H
