@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_PCM_H
-#define __P_PCM_H
+#ifndef MTX_P_PCM_H
+#define MTX_P_PCM_H
 
 #include "common/common_pch.h"
 
@@ -35,13 +35,14 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("PCM") : "PCM";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 protected:
+  virtual int process_packaged(packet_cptr packet);
   virtual void flush_impl();
 };
 
-#endif // __P_PCM_H
+#endif // MTX_P_PCM_H
