@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_TEXTSUBS_H
-#define __P_TEXTSUBS_H
+#ifndef MTX_P_TEXTSUBS_H
+#define MTX_P_TEXTSUBS_H
 
 #include "common/common_pch.h"
 
@@ -33,7 +33,7 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("text subtitles") : "text subtitles";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
@@ -42,4 +42,4 @@ private:
   static boost::regex s_re_remove_cr, s_re_translate_nl, s_re_remove_trailing_nl;
 };
 
-#endif  // __P_TEXTSUBS_H
+#endif  // MTX_P_TEXTSUBS_H
