@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_TTA_H
-#define __P_TTA_H
+#ifndef MTX_P_TTA_H
+#define MTX_P_TTA_H
 
 #include "common/common_pch.h"
 
@@ -30,10 +30,10 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("TTA") : "TTA";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
-#endif // __P_TTA_H
+#endif // MTX_P_TTA_H
