@@ -11,8 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_VC1_H
-#define __P_VC1_H
+#ifndef MTX_P_VC1_H
+#define MTX_P_VC1_H
 
 #include "common/common_pch.h"
 
@@ -33,7 +33,7 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("VC1") : "VC1";
   };
 
@@ -46,4 +46,4 @@ protected:
   virtual void add_timecodes_to_parser(packet_cptr &packet);
 };
 
-#endif // __P_VC1_H
+#endif // MTX_P_VC1_H
