@@ -12,8 +12,8 @@
    Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __P_VOBBTN_H
-#define __P_VOBBTN_H
+#ifndef MTX_P_VOBBTN_H
+#define MTX_P_VOBBTN_H
 
 #include "common/common_pch.h"
 
@@ -32,10 +32,10 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const std::string get_format_name(bool translate = true) {
+  virtual const std::string get_format_name(bool translate = true) const {
     return translate ? Y("VobBtn") : "VobBtn";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
-#endif // __P_VOBBTN_H
+#endif // MTX_P_VOBBTN_H
