@@ -26,9 +26,6 @@ vp8_video_packetizer_c::vp8_video_packetizer_c(generic_reader_c *p_reader,
 {
   m_timecode_factory_application_mode = TFA_SHORT_QUEUEING;
 
-  if (get_cue_creation() == CUE_STRATEGY_UNSPECIFIED)
-    set_cue_creation(CUE_STRATEGY_IFRAMES);
-
   set_track_type(track_video);
   set_codec_id(MKV_V_VP8);
 }
