@@ -54,13 +54,14 @@ write_changes(options_cptr &options,
   ids_to_write.push_back(KaxTracks::ClassInfos.GlobalId);
   ids_to_write.push_back(KaxTags::ClassInfos.GlobalId);
   ids_to_write.push_back(KaxChapters::ClassInfos.GlobalId);
+  ids_to_write.push_back(KaxAttachments::ClassInfos.GlobalId);
 
   for (auto &id_to_write : ids_to_write) {
     for (auto &target : options->m_targets) {
-      if (!target->m_level1_element)
+      if (!target->get_level1_element())
         continue;
 
-      EbmlMaster &l1_element = *target->m_level1_element;
+      EbmlMaster &l1_element = *target->get_level1_element();
 
       if (id_to_write != l1_element.Generic().GlobalId)
         continue;
@@ -118,7 +119,7 @@ run(options_cptr &options) {
 static
 void setup() {
   mtx_common_init("mkvpropedit");
-  clear_list_of_unique_uint32(UNIQUE_ALL_IDS);
+  clear_list_of_unique_numbers(UNIQUE_ALL_IDS);
   version_info = get_version_info("mkvpropedit", vif_full);
 }
 
